description property

  1. @override
String description
final

A description of this command, included in usage.

Implementation

@override
final description =
    'Get the document by the path, eg. `col1/doc1`.\n'
    'Command is recursive by default and will get all nested documents and collections and save them to the output JSON';